@@ -19,7 +19,12 @@
 
 #include <gz/common/MeshManager.hh>
 #include <gz/common/Console.hh>
-#include <gz/rendering.hh>
+#include <gz/math/Helpers.hh>
+
+#include <gz/rendering/Camera.hh>
+#include <gz/rendering/Capsule.hh>
+#include <gz/rendering/Scene.hh>
+#include <gz/rendering/Visual.hh>
 
 #include "SceneManager.hh"
 #include "SceneManagerPrivate.hh"
@@ -36,6 +41,7 @@ SceneManager::SceneManager() :
 //////////////////////////////////////////////////
 SceneManager::~SceneManager()
 {
+  this->Fini();
   delete this->pimpl;
 }
 
@@ -153,8 +159,8 @@ SceneManagerPrivate::SceneManagerPrivate() :
 //////////////////////////////////////////////////
 SceneManagerPrivate::~SceneManagerPrivate()
 {
-  delete currentSceneManager;
-  delete newSceneManager;
+    newSceneManager.reset();
+    currentSceneManager.reset();
 }
 
 //////////////////////////////////////////////////
@@ -165,6 +171,7 @@ void SceneManagerPrivate::Load()
 //////////////////////////////////////////////////
 void SceneManagerPrivate::Init()
 {
+//! [init scene manager]
   // listen for pre-render events
   this->preRenderConn = gazebo::event::Events::ConnectPreRender(
         std::bind(&SceneManagerPrivate::UpdateScenes, this));
@@ -213,12 +220,17 @@ void SceneManagerPrivate::Init()
   // listen for to pose updates
   this->poseSub = this->transportNode->Subscribe("~/pose/local/info",
       &SceneManagerPrivate::OnPoseUpdate, this);
+//! [init scene manager]
 }
 
 //////////////////////////////////////////////////
 void SceneManagerPrivate::Fini()
 {
-  // TODO(anyone): disconnect
+  // block all message receival during cleanup
+  std::lock_guard<std::mutex> generalLock(this->generalMutex);
+  std::lock_guard<std::mutex> poseLock(this->poseMutex);
+
+  this->transportNode->Fini();
 }
 
 //////////////////////////////////////////////////
@@ -450,6 +462,11 @@ void SceneManagerPrivate::OnLightUpdate(::ConstLightPtr &_lightMsg)
   // wait for update unlock before adding message
   std::lock_guard<std::mutex> lock(this->generalMutex);
 
+  if (this->currentSceneManager == nullptr || this->newSceneManager == nullptr)
+  {
+    return;
+  }
+
   this->currentSceneManager->OnLightUpdate(_lightMsg);
   this->newSceneManager->OnLightUpdate(_lightMsg);
 }
@@ -460,6 +477,11 @@ void SceneManagerPrivate::OnModelUpdate(::ConstModelPtr &_modelMsg)
   // wait for update unlock before adding message
   std::lock_guard<std::mutex> lock(this->generalMutex);
 
+  if (this->currentSceneManager == nullptr || this->newSceneManager == nullptr)
+  {
+    return;
+  }
+
   this->currentSceneManager->OnModelUpdate(_modelMsg);
   this->newSceneManager->OnModelUpdate(_modelMsg);
 }
@@ -470,6 +492,11 @@ void SceneManagerPrivate::OnJointUpdate(::ConstJointPtr &_jointMsg)
   // wait for update unlock before adding message
   std::lock_guard<std::mutex> lock(this->generalMutex);
 
+  if (this->currentSceneManager == nullptr || this->newSceneManager == nullptr)
+  {
+    return;
+  }
+
   this->currentSceneManager->OnJointUpdate(_jointMsg);
   this->newSceneManager->OnJointUpdate(_jointMsg);
 }
@@ -480,6 +507,11 @@ void SceneManagerPrivate::OnVisualUpdate(::ConstVisualPtr &_visualMsg)
   // wait for update unlock before adding message
   std::lock_guard<std::mutex> lock(this->generalMutex);
 
+  if (this->currentSceneManager == nullptr || this->newSceneManager == nullptr)
+  {
+    return;
+  }
+
   this->currentSceneManager->OnVisualUpdate(_visualMsg);
   this->newSceneManager->OnVisualUpdate(_visualMsg);
 }
@@ -490,6 +522,11 @@ void SceneManagerPrivate::OnSensorUpdate(::ConstSensorPtr &_sensorMsg)
   // wait for update unlock before adding message
   std::lock_guard<std::mutex> lock(this->generalMutex);
 
+  if (this->currentSceneManager == nullptr || this->newSceneManager == nullptr)
+  {
+    return;
+  }
+
   this->currentSceneManager->OnSensorUpdate(_sensorMsg);
   this->newSceneManager->OnSensorUpdate(_sensorMsg);
 }
@@ -500,6 +537,11 @@ void SceneManagerPrivate::OnPoseUpdate(::ConstPosesStampedPtr &_posesMsg)
   // wait for update unlock before adding message
   std::lock_guard<std::mutex> lock(this->poseMutex);
 
+  if (this->currentSceneManager == nullptr || this->newSceneManager == nullptr)
+  {
+    return;
+  }
+
   this->currentSceneManager->OnPoseUpdate(_posesMsg);
   this->newSceneManager->OnPoseUpdate(_posesMsg);
 }
@@ -510,6 +552,11 @@ void SceneManagerPrivate::OnRemovalUpdate(const std::string &_name)
   // wait for update unlock before adding message
   std::lock_guard<std::mutex> lock(this->poseMutex);
 
+  if (this->currentSceneManager == nullptr || this->newSceneManager == nullptr)
+  {
+    return;
+  }
+
   this->currentSceneManager->OnRemovalUpdate(_name);
   this->newSceneManager->OnRemovalUpdate(_name);
 }
@@ -846,6 +893,7 @@ void SubSceneManager::OnRemovalUpdate(const std::string &_name)
 void SubSceneManager::ProcessMessages()
 {
   // process each queued message
+//! [process message]
   this->ProcessLights();
   this->ProcessModels();
   this->ProcessJoints();
@@ -853,9 +901,10 @@ void SubSceneManager::ProcessMessages()
   this->ProcessSensors();
   this->ProcessPoses();
   this->ProcessRemovals();
+//! [process message]
 
   // flush changes to scene
-  this->activeScene->SetSimTime(this->timePosesReceived);
+  this->activeScene->SetTime(this->timePosesReceived);
   this->activeScene->PreRender();
 }
 
@@ -1458,6 +1507,21 @@ void SubSceneManager::ProcessCone(
 }
 
 //////////////////////////////////////////////////
+void SubSceneManager::ProcessCapsule(
+    const gazebo::msgs::Geometry & _geometryMsg, VisualPtr _parent)
+{
+  // \todo(anyone) needs gazebo capsule msg
+  CapsulePtr capsule = this->activeScene->CreateCapsule();
+  // Const gazebo::msgs::CapsuleGeom &capsuleMsg = _geometryMsg.capsule();
+  // Double x = 2 * capsuleMsg.radius();
+  // Double y = 2 * capsuleMsg.radius();
+  // Double z = capsuleMsg.length();
+  // _parent->SetLocalScale(x, y, z);
+  _parent->AddGeometry(std::dynamic_pointer_cast<Geometry>(capsule));
+}
+
+//////////////////////////////////////////////////
+//! [process cylinder]
 void SubSceneManager::ProcessCylinder(
     const gazebo::msgs::Geometry &_geometryMsg, VisualPtr _parent)
 {
@@ -1469,6 +1533,7 @@ void SubSceneManager::ProcessCylinder(
   _parent->SetLocalScale(x, y, z);
   _parent->AddGeometry(cylinder);
 }
+//! [process cylinder]
 
 //////////////////////////////////////////////////
 void SubSceneManager::ProcessEmpty(const gazebo::msgs::Geometry&, VisualPtr)
@@ -1770,10 +1835,14 @@ void SubSceneManager::CreateGeometryFunctionMap()
   this->geomFunctions[gazebo::msgs::Geometry::BOX] =
       &SubSceneManager::ProcessBox;
 
-  // TODO(anyone): enable when cone protobuf msg created
+  // todo(anyone): enable when cone protobuf msg is created
   // this->geomFunctions[gazebo::msgs::Geometry::CONE] =
   //     &SubSceneManager::ProcessCone;
 
+  // todo(anyone): enable when capsule protobuf msg is created
+  // this->geomFunctions[gazebo::msgs::Geometry::CAPSULE] =
+  //     &SubSceneManager::ProcessSphere;
+
   this->geomFunctions[gazebo::msgs::Geometry::CYLINDER] =
       &SubSceneManager::ProcessCylinder;
 
@@ -1801,12 +1870,12 @@ CurrentSceneManager::~CurrentSceneManager()
 }
 
 //////////////////////////////////////////////////
+//! [on update pose]
 void CurrentSceneManager::OnPoseUpdate(::ConstPosesStampedPtr &_posesMsg)
 {
   // record pose timestamp
-  int sec = _posesMsg->time().sec();
-  int nsec = _posesMsg->time().nsec();
-  this->timePosesReceived = common::Time(sec, nsec);
+  this->timePosesReceived = std::chrono::seconds(_posesMsg->time().sec()) +
+      std::chrono::nanoseconds(_posesMsg->time().nsec());
 
   // process each pose in message
   for (int i = 0; i < _posesMsg->pose_size(); ++i)
@@ -1817,6 +1886,7 @@ void CurrentSceneManager::OnPoseUpdate(::ConstPosesStampedPtr &_posesMsg)
     this->poseMsgs[name] = pose;
   }
 }
+//! [on update pose]
 
 //////////////////////////////////////////////////
 void CurrentSceneManager::ClearMessages()
@@ -2043,9 +2113,8 @@ void NewSceneManager::ProcessPoses()
 void NewSceneManager::ProcessPoses(const gazebo::msgs::PosesStamped &_posesMsg)
 {
   // record pose timestamp
-  int sec = _posesMsg.time().sec();
-  int nsec = _posesMsg.time().nsec();
-  this->timePosesReceived = common::Time(sec, nsec);
+  this->timePosesReceived = std::chrono::seconds(_posesMsg.time().sec()) +
+      std::chrono::nanoseconds(_posesMsg.time().nsec());
 
   // process each pose in list
   for (int i = 0; i < _posesMsg.pose_size(); ++i)
