@@ -118,6 +118,18 @@ void OgreLight::SetAttenuationRange(double _range)
   this->UpdateAttenuation();
 }
 
+//////////////////////////////////////////////////
+double OgreLight::Intensity() const
+{
+  return this->ogreLight->getPowerScale();
+}
+
+//////////////////////////////////////////////////
+void OgreLight::SetIntensity(double _intensity)
+{
+  this->ogreLight->setPowerScale(_intensity);
+}
+
 //////////////////////////////////////////////////
 bool OgreLight::CastShadows() const
 {
