@@ -15,17 +15,17 @@
  *
  */
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Filesystem.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Filesystem.hh>
 
-#include "ignition/rendering/ShaderParams.hh"
-#include "ignition/rendering/ogre/OgreMaterial.hh"
-#include "ignition/rendering/ogre/OgreConversions.hh"
-#include "ignition/rendering/ogre/OgreRenderEngine.hh"
-#include "ignition/rendering/ogre/OgreRTShaderSystem.hh"
-#include "ignition/rendering/ogre/OgreScene.hh"
+#include "gz/rendering/ShaderParams.hh"
+#include "gz/rendering/ogre/OgreMaterial.hh"
+#include "gz/rendering/ogre/OgreConversions.hh"
+#include "gz/rendering/ogre/OgreRenderEngine.hh"
+#include "gz/rendering/ogre/OgreRTShaderSystem.hh"
+#include "gz/rendering/ogre/OgreScene.hh"
 
-using namespace ignition;
+using namespace gz;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -44,11 +44,18 @@ void OgreMaterial::Destroy()
 {
   if (!this->Scene()->IsInitialized())
     return;
-
+  std::string materialName;
   Ogre::MaterialManager &matManager = Ogre::MaterialManager::getSingleton();
 #if OGRE_VERSION_LT_1_11_0
   if (!this->ogreMaterial.isNull())
   {
+    materialName = this->ogreMaterial->getName();
+
+    this->ogreTexState->setBlank();
+    auto indexUnitStateToRemove =
+      this->ogrePass->getTextureUnitStateIndex(this->ogreTexState);
+    this->ogrePass->removeTextureUnitState(indexUnitStateToRemove);
+
     matManager.remove(this->ogreMaterial->getName());
     this->ogreMaterial.setNull();
   }
@@ -59,6 +66,32 @@ void OgreMaterial::Destroy()
     this->ogreMaterial.reset();
   }
 #endif
+  auto &textureManager = Ogre::TextureManager::getSingleton();
+  auto iend = textureManager.getResourceIterator().end();
+  for (auto i = textureManager.getResourceIterator().begin(); i != iend;)
+  {
+    // A use count of 4 means that only RGM, RM and MeshManager have
+    // references RGM has one (this one) and RM has 2 (by name and by handle)
+    // and MeshManager keep another one int the template
+    Ogre::Resource* res = i->second.get();
+    if (i->second.useCount() == 4)
+    {
+      if (this->textureName == res->getName() &&
+        res->getName().find(
+          scene->Name() + "::RenderTexture") == std::string::npos)
+      {
+        OgreScenePtr s = std::dynamic_pointer_cast<OgreScene>(this->Scene());
+        s->ClearMaterialsCache(this->textureName);
+        this->Scene()->UnregisterMaterial(materialName);
+        if (i->second.useCount() == 3)
+        {
+          textureManager.remove(res->getHandle());
+        }
+        break;
+      }
+    }
+    ++i;
+  }
 }
 
 //////////////////////////////////////////////////
@@ -350,7 +383,7 @@ void OgreMaterial::UpdateShaderParams()
 void OgreMaterial::UpdateShaderParams(ConstShaderParamsPtr _params,
     Ogre::GpuProgramParametersSharedPtr _ogreParams)
 {
-  for (const auto name_param : *_params)
+  for (const auto & name_param : *_params)
   {
     if (ShaderParam::PARAM_FLOAT == name_param.second.Type())
     {
