@@ -39,15 +39,11 @@ class LightTest : public testing::Test,
 /////////////////////////////////////////////////
 void LightTest::Light(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   // create and populate scene
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
            << "' is not supported" << std::endl;
     return;
   }
