@@ -19,9 +19,9 @@
 
 #include "test_config.h"  // NOLINT(build/include)
 
-#include "ignition/rendering/PixelFormat.hh"
+#include "gz/rendering/PixelFormat.hh"
 
-using namespace ignition;
+using namespace gz;
 using namespace rendering;
 
 /////////////////////////////////////////////////
@@ -31,26 +31,52 @@ TEST(PixelFormatTest, PixelUtil)
   EXPECT_EQ(3u, PixelUtil::BytesPerPixel(format));
   EXPECT_EQ(1u, PixelUtil::BytesPerChannel(format));
   EXPECT_EQ(3072u, PixelUtil::MemorySize(format, 32, 32));
+  EXPECT_EQ("R8G8B8", PixelUtil::Name(format));
+  EXPECT_EQ(format, PixelUtil::Enum("R8G8B8"));
 
   format = PF_FLOAT32_R;
   EXPECT_EQ(4u, PixelUtil::BytesPerPixel(format));
   EXPECT_EQ(4u, PixelUtil::BytesPerChannel(format));
   EXPECT_EQ(4096u, PixelUtil::MemorySize(format, 32, 32));
+  EXPECT_EQ("FLOAT32_R", PixelUtil::Name(format));
+  EXPECT_EQ(format, PixelUtil::Enum("FLOAT32_R"));
 
   format = PF_FLOAT32_RGB;
   EXPECT_EQ(12u, PixelUtil::BytesPerPixel(format));
   EXPECT_EQ(4u, PixelUtil::BytesPerChannel(format));
   EXPECT_EQ(12288u, PixelUtil::MemorySize(format, 32, 32));
+  EXPECT_EQ("FLOAT32_RGB", PixelUtil::Name(format));
+  EXPECT_EQ(format, PixelUtil::Enum("FLOAT32_RGB"));
 
   format = PF_FLOAT32_RGBA;
   EXPECT_EQ(16u, PixelUtil::BytesPerPixel(format));
   EXPECT_EQ(4u, PixelUtil::BytesPerChannel(format));
   EXPECT_EQ(16384u, PixelUtil::MemorySize(format, 32, 32));
+  EXPECT_EQ("FLOAT32_RGBA", PixelUtil::Name(format));
+  EXPECT_EQ(format, PixelUtil::Enum("FLOAT32_RGBA"));
 
   format = PF_L16;
   EXPECT_EQ(2u, PixelUtil::BytesPerPixel(format));
   EXPECT_EQ(2u, PixelUtil::BytesPerChannel(format));
   EXPECT_EQ(2048u, PixelUtil::MemorySize(format, 32, 32));
+  EXPECT_EQ("L16", PixelUtil::Name(format));
+  EXPECT_EQ(format, PixelUtil::Enum("L16"));
+
+  format = PF_R8G8B8A8;
+  EXPECT_EQ(4u, PixelUtil::BytesPerPixel(format));
+  EXPECT_EQ(1u, PixelUtil::BytesPerChannel(format));
+  EXPECT_EQ(4096u, PixelUtil::MemorySize(format, 32, 32));
+}
+
+/////////////////////////////////////////////////
+TEST(PixelFormatTest, PixelUtilInvalid)
+{
+  PixelFormat format = static_cast<PixelFormat>(16);
+
+  EXPECT_EQ(PF_UNKNOWN, PixelUtil::Sanitize(format));
+  EXPECT_EQ("UNKNOWN", PixelUtil::Name(format));
+
+  EXPECT_EQ(PF_UNKNOWN, PixelUtil::Enum("invalid"));
 }
 
 int main(int argc, char **argv)
