@@ -66,14 +66,10 @@ class VisualTest : public testing::Test,
 /////////////////////////////////////////////////
 void VisualTest::Material(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -155,14 +151,10 @@ TEST_P(VisualTest, Material)
 /////////////////////////////////////////////////
 void VisualTest::Children(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -228,14 +220,10 @@ TEST_P(VisualTest, Children)
 /////////////////////////////////////////////////
 void VisualTest::Scale(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -323,14 +311,10 @@ TEST_P(VisualTest, Scale)
 /////////////////////////////////////////////////
 void VisualTest::UserData(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -426,14 +410,10 @@ TEST_P(VisualTest, UserData)
 /////////////////////////////////////////////////
 void VisualTest::Geometry(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -505,14 +485,10 @@ TEST_P(VisualTest, Geometry)
 /////////////////////////////////////////////////
 void VisualTest::VisibilityFlags(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                                                                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -576,14 +552,10 @@ TEST_P(VisualTest, VisibilityFlags)
 /////////////////////////////////////////////////
 void VisualTest::BoundingBox(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                                                                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -621,14 +593,10 @@ TEST_P(VisualTest, BoundingBox)
 /////////////////////////////////////////////////
 void VisualTest::Wireframe(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                                                                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported\n";
     return;
   }
@@ -654,14 +622,10 @@ TEST_P(VisualTest, Wireframe)
 /////////////////////////////////////////////////
 void VisualTest::Clone(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                                                                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
